[bitbake-devel] [PATCH 3/9] toaster: update api to include local_source_dir

Elliot Smith elliot.smith at intel.com
Mon Aug 22 15:42:30 UTC 2016


From: Sujith H <sujith.h at gmail.com>

Add an additional argument to the api to handle
local_source_dir which is the value user passes
to import non-git layers.

[YOCTO #9913]

Signed-off-by: Sujith H <sujith.h at gmail.com>
Signed-off-by: Elliot Smith <elliot.smith at intel.com>
---
 bitbake/lib/toaster/toastergui/api.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/bitbake/lib/toaster/toastergui/api.py b/bitbake/lib/toaster/toastergui/api.py
index b57f670..8dde128 100644
--- a/bitbake/lib/toaster/toastergui/api.py
+++ b/bitbake/lib/toaster/toastergui/api.py
@@ -135,7 +135,7 @@ class XhrLayer(View):
           Method: POST
 
           Args:
               vcs_url, dirpath, commit, up_branch, summary, description
 
               add_dep = append a layerversion_id as a dependency
               rm_dep = remove a layerversion_id as a depedency
@@ -166,6 +166,8 @@ class XhrLayer(View):
             layer_version.layer.summary = request.POST["summary"]
         if "description" in request.POST:
             layer_version.layer.description = request.POST["description"]
+        if "local_source_dir" in request.POST:
+            layer_version.layer.local_source_dir = request.POST["local_source_dir"]
 
         if "add_dep" in request.POST:
             lvd = LayerVersionDependency(
@@ -135,7 +135,7 @@ class XhrLayer(View):
 
           Args:
-              vcs_url, dirpath, commit, up_branch, summary, description
+              vcs_url, dirpath, commit, up_branch, summary, description, local_source_dir
 
               add_dep = append a layerversion_id as a dependency
-- 
2.7.4




More information about the bitbake-devel mailing list